==> nextcloud-app-deck-1%3A0.6.6-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/deck/l10n/sq.js <==
OC.L10N.register(
    "deck",
    {
    "Hours" : "Orët",
    "Minutes" : "Minutat",
    "Deck" : "Shto paisjen U2F",
    "Finished" : "Përfunduar",
    "To review" : "Për rishikim",
    "Action needed" : "Nevoitet veprim",
    "Later" : "Më vonë",
    "To do" : "Për t'u bërë",
    "Doing" : "Duke e bërë",
    "Done" : "Përfunduar",
    "The file was uploaded" : "Skedari u ngarkua",
    "Add a new stack" : "Shto një raft të ri",
    "Submit" : "Dërgo",
    "Show archived cards" : "Trego kartat e arkivuara",
    "Hide archived cards" : "Fsheh kartat e arkivuara ",
    "All Boards" : "Të gjitha Tabelat ",
    "Archived boards" : "Borde të arkivuara",
    "Actions" : "Veprimet",
    "Enter a card title" : "Fusni një titull karte",
    "Add card" : "Shto kartë",
    "Close" : "Mbyll",
    "Sharing" : "Shpërndaj ",
    "Tags" : "Etiketa",
    "Select users or groups to share with" : "Shpërndajeni duke zgjedhur përdorues ose grupe ",
    "No matching user or group found." : "Nuk u gjet asnjë përdorues ose grup i përputhshëm.",
    "Loading" : "Po ngarkohet",
    "Edit" : "Edito",
    "Share" : "Ndaj ",
    "Manage" : "Menaxho",
    "Discard share" : "Fshi ndarjen",
    "Create" : "Krijo",
    "Create a new tag" : "Krijo një etiketë të re",
    "Status" : "Status",
    "Title" : "Titull",
    "Members" : "Anëtar",
    "More actions" : "Më tepër veprime ",
    "Edit board" : "Tabela e editimeve",
    "Archive board" : "Arkivo bordin",
    "Unarchive board" : "Hiq bordin nga arkivi",
    "Delete board" : "Fshij bordin",
    "Create new board" : "Krijo bord të ri",
    "New board title" : "Titull i ri bordi",
    "Cancel upload" : "Anullo ngarkimin",
    "by" : "nga",
    "Modified:" : "Modifikuar:",
    "Created:" : "Krijuar:",
    "Choose a tag" : "Zgjidh një etiketë",
    "Add a tag" : "Shto një etiketë",
    "Select tags" : "Përzgjidh etiketat",
    "Due date" : "Data e vendosur",
    "Click to set" : "Kliko për të vendosur",
    "Remove due date" : "Hiq datën e mbarimit",
    "Description" : "Përshkrim",
    "Saved" : "I/E ruajtur",
    "Formatting help" : "Ndihmë formatimi",
    "Add a card description…" : "Shto një përshkrim të kartës...",
    "Shared boards" : "Tabela të shpërndara",
    "Move board to archive" : "Lëviz tabelen në arkivë",
    "Create a new board" : "Krijo një tablë të re"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-deck-1%3A0.8.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/deck/l10n/sq.js <==
OC.L10N.register(
    "deck",
    {
    "Hours" : "Orët",
    "Minutes" : "Minutat",
    "File already exists" : "Skedari ekziston tashmë",
    "Deck" : "Shto paisjen U2F",
    "Personal" : "Personale",
    "Finished" : "Përfunduar",
    "To review" : "Për rishikim",
    "Action needed" : "Nevoitet veprim",
    "Later" : "Më vonë",
    "To do" : "Për t'u bërë",
    "Doing" : "Duke e bërë",
    "Done" : "Përfunduar",
    "The file was uploaded" : "Skedari u ngarkua",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Kartela e ngarkuar tejkalon udhëzimin MAX_FILE_SIZE që qe përcaktuar te formulari HTML",
    "No file was uploaded" : "S’u ngarkua kartelë",
    "Missing a temporary folder" : "Mungon një dosje e përkohshme",
    "Add a new stack" : "Shto një raft të ri",
    "Submit" : "Dërgo",
    "Show archived cards" : "Trego kartat e arkivuara",
    "Hide archived cards" : "Fsheh kartat e arkivuara ",
    "All Boards" : "Të gjitha Tabelat ",
    "Archived boards" : "Borde të arkivuara",
    "Actions" : "Veprimet",
    "Enter a card title" : "Fusni një titull karte",
    "Add card" : "Shto kartë",
    "Close" : "Mbyll",
    "Sharing" : "Shpërndaj ",
    "Tags" : "Etiketa",
    "Select users or groups to share with" : "Shpërndajeni duke zgjedhur përdorues ose grupe ",
    "Group" : "Grup",
    "Circle" : "Rreth",
    "No matching user or group found." : "Nuk u gjet asnjë përdorues ose grup i përputhshëm.",
    "Loading" : "Po ngarkohet",
    "Edit" : "Edito",
    "Share" : "Ndaj ",
    "Manage" : "Menaxho",
    "Discard share" : "Fshi ndarjen",
    "Delete tag" : "Fshi etiketën",
    "Create" : "Krijo",
    "Create a new tag" : "Krijo një etiketë të re",
    "Status" : "Status",
    "Title" : "Titull",
    "Members" : "Anëtar",
    "More actions" : "Më tepër veprime ",
    "Edit board" : "Tabela e editimeve",
    "Archive board" : "Arkivo bordin",
    "Unarchive board" : "Hiq bordin nga arkivi",
    "Delete board" : "Fshij bordin",
    "Create new board" : "Krijo bord të ri",
    "New board title" : "Titull i ri bordi",
    "Cancel upload" : "Anullo ngarkimin",
    "by" : "nga",
    "Modified:" : "Modifikuar:",
    "Created:" : "Krijuar:",
    "Choose a tag" : "Zgjidh një etiketë",
    "Add a tag" : "Shto një etiketë",
    "Select tags" : "Përzgjidh etiketat",
    "Assign users" : "Cakto përdorues",
    "Due date" : "Data e vendosur",
    "Click to set" : "Kliko për të vendosur",
    "Remove due date" : "Hiq datën e mbarimit",
    "Description" : "Përshkrim",
    "Attachments" : "Bashkangjitjet",
    "Saved" : "I/E ruajtur",
    "Unsaved changes" : "Ndryshime të paruajtura",
    "Formatting help" : "Ndihmë formatimi",
    "Upload attachment" : "Ngarko bashkëngjitje",
    "Add a card description…" : "Shto një përshkrim të kartës...",
    "Shared boards" : "Tabela të shpërndara",
    "Move board to archive" : "Lëviz tabelen në arkivë",
    "Create a new board" : "Krijo një tablë të re",
    "Settings" : "Rregullimet"
},
"nplurals=2; plural=(n != 1);");
